CREATE SEQUENCE messages_id_seq;
CREATE TABLE messages 
 (
    id BIGINT NOT NULL DEFAULT nextval('messages_id_seq'), 
    ip VARCHAR(110) NOT NULL DEFAULT '0',
    rtime TIMESTAMP NOT NULL,
    facsev INTEGER NOT NULL, 
    mtime TIMESTAMP,
    host VARCHAR(129) DEFAULT NULL, 
    ident VARCHAR(80) DEFAULT NULL, 
    pid VARCHAR(128), 
    event INT,
    msg TEXT NOT NULL, 
    fts TEXT DEFAULT '',
    PRIMARY KEY (id)
 );
CREATE INDEX messages_fts_idx ON messages USING gin( to_tsvector('english', fts) );

CREATE SEQUENCE users_id_seq;
CREATE TABLE users
 (
    id INT NOT NULL DEFAULT nextval('users_id_seq'),
    name VARCHAR(128),
    password VARCHAR(128),
    real_name VARCHAR(128),
    email VARCHAR(128),
    default_filter_id INT,
    PRIMARY KEY (id),
    UNIQUE(name)
 );
INSERT INTO users(name, password) VALUES('admin', '21232f297a57a5a743894a0e4a801fc3');

CREATE SEQUENCE filters_id_seq;
CREATE TABLE filters 
 (
    id INT NOT NULL DEFAULT nextval('filters_id_seq'),
    name VARCHAR(128) NOT NULL,
    query VARCHAR(1024) NOT NULL,
    owner_id INT REFERENCES users (id) ON DELETE CASCADE,
    parent_id INT DEFAULT NULL,
    PRIMARY KEY (id),
    UNIQUE (name)
 );
INSERT INTO filters(name, query) VALUES('All', '');
INSERT INTO filters(name, query, parent_id) VALUES('localhost', 'ip=(127.0.0.1)', 1);
INSERT INTO filters(name, query, parent_id) VALUES('critical or worse', 'sev=(emergency alert critical)', 1);
INSERT INTO filters(name, query, parent_id) VALUES('mail logs', 'fac=(mail)', 1);
INSERT INTO filters(name, query, parent_id) VALUES('authentication', 'fac=(auth authpriv)', 1);
INSERT INTO filters(name, query, parent_id) VALUES('authentication failure', 'msg=(fail)', 5);
INSERT INTO filters(name, query, parent_id) VALUES('audit', 'msg:[AUDIT]', 1);
INSERT INTO filters(name, query, parent_id) VALUES('all except audit', '-msg:[AUDIT]', 1);

CREATE SEQUENCE reports_id_seq;
CREATE TABLE reports
 (
    id INT NOT NULL DEFAULT nextval('reports_id_seq'),
    name VARCHAR(255),
    description VARCHAR,
    userid INT NOT NULL DEFAULT 0,
    recipient_type INT NOT NULL DEFAULT 0,
    recipients TEXT NOT NULL,
    filter VARCHAR(128) NOT NULL,
    interval_type INT NOT NULL DEFAULT 0,
    last_generated INT NOT NULL DEFAULT 0,
    PRIMARY KEY (id),
    FOREIGN KEY (filter) REFERENCES filters (name) ON DELETE CASCADE
 );

CREATE TYPE import_states AS ENUM ('planned', 'started', 'finished', 'failed');
CREATE SEQUENCE tables_registry_id_seq;
CREATE TABLE tables_registry
 (
    id INT NOT NULL DEFAULT nextval('tables_registry_id_seq'),
    name VARCHAR(128),
    location BIT(3),
    date TIMESTAMP,
    import_status import_states,
    nums INT,
    PRIMARY KEY(id),
    UNIQUE(name)
 );

CREATE SEQUENCE settings_id_seq;
CREATE TABLE settings
 (
    id INT NOT NULL DEFAULT nextval('settings_id_seq'),
    local_storage_path VARCHAR,
    remote_storage_path VARCHAR,
    keep_in_db INTEGER,
    keep_in_local INTEGER,
    keep_in_remote INTEGER,
    create_fts_index BOOLEAN,
    monitor_host VARCHAR,
    use_ninja BOOLEAN,
	host_info_url VARCHAR,
	use_ldap BOOLEAN NOT NULL DEFAULT FALSE,
	compressed_filesize_modifier INT NOT NULL DEFAULT 100,
	min_disk_size_free INT NOT NULL DEFAULT 500,
    PRIMARY KEY(id)
 );
INSERT INTO settings(local_storage_path, remote_storage_path, keep_in_db, keep_in_local, keep_in_remote, create_fts_index, monitor_host, use_ninja, host_info_url) VALUES('/opt/logserver/archive', NULL, 5, 5, 5, TRUE, '', FALSE, '');

CREATE SEQUENCE summary_reports_id_seq;
CREATE TABLE summary_reports
 (
    id INT NOT NULL DEFAULT nextval('summary_reports_id_seq'),
    filter_id INT NOT NULL REFERENCES filters (id) ON DELETE CASCADE,
    PRIMARY KEY(id)
 );

CREATE SEQUENCE summary_reports_hosts_id_seq;
CREATE TABLE summary_reports_hosts
 (
    id INT NOT NULL DEFAULT nextval('summary_reports_hosts_id_seq'),
    summary_id INT NOT NULL REFERENCES summary_reports (id) ON DELETE CASCADE,
    host VARCHAR(129) DEFAULT NULL,
    count INT DEFAULT 0,
    PRIMARY KEY(id)
 );
