#!/usr/bin/php
<?php

set_include_path('.:/opt/logserver/gui/');
require ('libs/config.php');
require ('libs/database.php');
require ('comps/filters/model.php');

$progname = 'import_filters.php';

$model = new FiltersModel;

function import_children($node, $parentname, $selective = false)
{
	global $model;
	global $selected;

	if ($selective && !count($selected))
		return;

	foreach ($node->children() as $filter)
	{
		if ($selective)
		{
			$key = array_search($filter['name'], $selected);
			if ($key === FALSE)
				continue;
			else
				unset($selected[$key]);
		}

		if (!$model->exists($filter['name']))
		{
			$model->add_global_filter($filter['name'], $filter['query'], $parentname);
			import_children($filter, $filter['name'], $selective);
		}
		elseif ($model->is_global($filter['name'])
			&& $model->get_query($filter['name']) == $filter['query'])
		{
			import_children($filter, $filter['name'], $selective);
		}
	}
}

if ($argc < 2 || in_array($argv[1], array('--help', '-h')))
{
	echo "This script imports filters from an XML file\n";
	echo "Usage: $progname <filename> [filter ...]\n";
	echo "Notes:\n";
	echo "* if no filter is specified - all filters will be imported\n";
	echo "* if filter name contains spaces - enclose it in quotes\n";
	echo "* you must specify parent filters as well (except filter 'All')\n";
	exit(1);
}

if (($data = @file_get_contents($argv[1])) === FALSE)
{
	echo "Could not read from file {$argv[1]}\n";
	exit(1);
}

try
{
	$xml = new SimpleXMLElement($data);

	if ($argc == 2)
		import_children($xml->filters->filter[0], 'All');
	else
	{
		$selected = array_slice($argv, 2);

		import_children($xml->filters->filter[0], 'All', true);

		if (count($selected))
			echo "The following filters could not be imported: '"
				. implode("', '", $selected)
				. "'\nEither they don't exist or their parents were not specified\n";
	}
}
catch (Exception $e)
{
	echo "Could not import filters\n";
	exit(1);
}

exit(0);

?>
