#!/bin/bash

if [ $# -ne 3 ]; then
	echo "Usage: loaddir.sh <date> <time> <directory>"
	exit
fi

if [ ! -d $3 ]; then
	echo "Directory $3 does not exist"
	exit
fi

total_messages=0
total_seconds=0
avg_seconds=0
min_seconds=10000
max_seconds=0
total_mps=0
avg_mps=0
min_mps=1000000
max_mps=0

files=$(ls -1 $3 | wc -l)

service postgresql stop
sync
echo 3 > /proc/sys/vm/drop_caches
service postgresql start

for i in $(ls -1 $3); do
	messages=$(cat ${}/$i | wc -l)
	let total_messages=$total_messages+$messages

	timestamp1=$(date +%s)
	psql -U op5lsu op5lsu -t -c "SELECT load_to_table_function('$1', '$2', '$(pwd)/$3/$i');"
	timestamp2=$(date +%s)

	let seconds=$timestamp2-$timestamp1
	let total_seconds=$total_seconds+$seconds
	if [ $seconds -lt $min_seconds ]; then min_seconds=$seconds; fi
	if [ $seconds -gt $max_seconds ]; then max_seconds=$seconds; fi

	let mps=$messages/$seconds
	let total_mps=$total_mps+$mps
	if [ $mps -lt $min_mps ]; then min_mps=$mps; fi
	if [ $mps -gt $max_mps ]; then max_mps=$mps; fi
done

let avg_seconds=$total_seconds/$files
let avg_mps=$total_mps/$files

printf "Messages  : %s\n" $total_messages
printf "Time, s   :\n"
printf "    total : %s\n" $total_seconds
printf "    avg   : %s\n" $avg_seconds
printf "    min   : %s\n" $min_seconds
printf "    max   : %s\n" $max_seconds
printf "Speed, m/s:\n"
printf "    avg   : %s\n" $avg_mps
printf "    min   : %s\n" $min_mps
printf "    max   : %s\n" $max_mps
